import { ILabel, ILabelData, ILabelUpdate } from '../interfaces/controls/ILabel';
import { Control } from './Control';
/**
 * Label can be used to title and group different controls.
 */
export declare class Label extends Control<ILabelData> implements ILabel {
    /**
     * The text displayed on a label, presented to the participants.
     * Set this value using [setText]{@link Button.setText}
     */
    text: string;
    /**
     * The size of the text on the label, presented to the participants.
     * Set this value using [setTextSize]{@link Button.setTextSize}
     */
    textSize: string;
    /**
     * The color of the text on the label, presented to the participants.
     * Set this value using [setTextColor]{@link Button.setTextColor}
     */
    textColor: string;
    /**
     * Underlines the text on the label, presented to the participants.
     */
    underline: boolean;
    /**
     * Bolds the text on the label, presented to the participants.
     */
    bold: boolean;
    /**
     * Italicize to text on the label, presented ot the participants.
     */
    italic: boolean;
    /**
     * Sets a new text value for this label.
     */
    setText(text: string): Promise<void>;
    /**
     * Sets a progress value for this label.
     * A decimalized percentage (0.0 - 1.0)
     */
    setTextSize(textSize: string): Promise<void>;
    /**
     * Sets a new text color for this label.
     */
    setTextColor(textColor: string): Promise<void>;
    /**
     * Update this label on the server.
     */
    update(controlUpdate: ILabelUpdate): Promise<void>;
}
